BundleInfo class

class that holds queried application bundle information

Constructors

BundleInfo(String appName, String appIdentifier, String version, String buildNo)

Properties

appIdentifier → String
final
appName → String
final
buildNo → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic json) → BundleInfo